﻿namespace DataAccess
{
    using System.Collections.Generic;
    using System.Linq;

    partial class AdventureWorksEntities
    {
        public IEnumerable<ProductInfo> GetProductInfo(string categoryName, string modelName)
        {
            var query = from product in this.Products
                        join category in this.ProductCategories
                        on product.ProductCategoryID equals category.ProductCategoryID
                        where category.Name.StartsWith(categoryName)
                        join model in this.ProductModels
                        on product.ProductModelID equals model.ProductModelID
                        where model.Name.StartsWith(modelName)
                        select new ProductInfo
                        {
                            CategoryName = category.Name,
                            ModelName = model.Name,
                            ProductName = product.Name,
                            ProductNumber = product.ProductNumber
                        };

            return query.ToArray();
        }
    }

    public class ProductInfo
    {
        public string CategoryName { get; set; }
        public string ModelName { get; set; }
        public string ProductName { get; set; }
        public string ProductNumber { get; set; }
    }
}
